from setuptools import setup

setup(name='eecr_distributions',
      version='1.5',
      description='Gaussian and Binomial distributions',
      packages=['eecr_distributions'],
      author='Ernesto Cornejo - Udacity course 2020',
      author_email='ernestocornejo@hotmail.com',
      zip_safe=False)
